#
# This is the SPEC file for creating binary and source RPMs for the Qubes DB.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2013  Marek Marczykowski <marmarek@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#

%{!?python_sitearch: %define python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}

Name:		qubes-db
Version:	4.0.11
Release:	1%{?dist}
Summary:	QubesDB tools

Group:		Qubes
License:	GPL
URL:		http://www.qubes-os.org/

BuildRequires:	gcc
BuildRequires:	qubes-libvchan-xen-devel
BuildRequires:	systemd-devel
BuildRequires:	python-devel
BuildRequires:  python%{python3_pkgversion}-devel
Requires:	qubes-libvchan-xen
# XXX: VMM specific
Requires:   xen-libs >= 2001:4.6.1-20
Source0:    %{name}-%{version}.tar.gz

%description
QubesDB management tools and daemon.

%package libs
Summary:	QubesDB libs
Group:		Qubes

%description libs
QubesDB client library.

%package devel
Summary:	QubesDB client header files
Group:		Qubes
Requires:	qubes-db-libs

%description devel
Header files for QubesDB client library and daemon protocol.

%package -n python2-qubesdb
Summary:    Python2 bindings for QubesDB
Requires:   qubes-db-libs
%{?python_provide:%python_provide python2-qubesdb}

%description -n python2-qubesdb
Python bindings for QubesDB

%package -n python%{python3_pkgversion}-qubesdb
Summary:    Python%{python3_pkgversion} bindings for QubesDB
Requires:   qubes-db-libs
%{?python_provide:%python_provide python%{python3_pkgversion}-qubesdb}

%description -n python%{python3_pkgversion}-qubesdb
Python3 bindings for QubesDB

%prep
%setup -q 

%build
%{?set_build_flags}
make %{?_smp_mflags} PYTHON=%{__python2} BACKEND_VMM=xen all
make %{?_smp_mflags} PYTHON=%{__python3} -C python all

%install
make install \
         PYTHON=%{__python2} \
         DESTDIR=%{buildroot} \
         LIBDIR=%{_libdir} \
         BINDIR=%{_bindir} \
         SBINDIR=%{_sbindir}
make -C python install \
         PYTHON=%{__python3} \
         DESTDIR=%{buildroot} \
         LIBDIR=%{_libdir} \
         BINDIR=%{_bindir} \
         SBINDIR=%{_sbindir}

%files
%doc
%{_bindir}/qubesdb-cmd
%{_bindir}/qubesdb-read
%{_bindir}/qubesdb-read-bool
%{_bindir}/qubesdb-write
%{_bindir}/qubesdb-rm
%{_bindir}/qubesdb-multiread
%{_bindir}/qubesdb-list
%{_bindir}/qubesdb-watch
%{_sbindir}/qubesdb-daemon

%files libs
%{_libdir}/libqubesdb.so

%files -n python2-qubesdb
%{python2_sitearch}/QubesDB-*egg-info
%{python2_sitearch}/qubesdb.so

%files -n python%{python3_pkgversion}-qubesdb
%{python3_sitearch}/QubesDB-*egg-info
%{python3_sitearch}/qubesdb.*.so

%files devel
/usr/include/qubesdb.h
/usr/include/qubesdb-client.h

%changelog
* Mon Sep 09 2019 Qubes OS Team <qubes-devel@groups.google.com>
- For complete changelog see: https://github.com/QubesOS/qubes-core-qubesdb

* Mon Sep 09 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3e5dcd0
- version 4.0.11

* Fri Aug 09 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - fc78f6d
- travis: update Fedora versions, switch to xenial

* Fri Aug 09 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 799a0f8
- python: fix gcc -Wsign-compare warnings

* Fri Aug 09 2019 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 7c7a33f
- daemon: fix handling empty entries

* Fri Aug 09 2019 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 598cc4e
- Daemon: fixed crash when trying to remove '/'

* Fri Aug 09 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 9c22f8a
- spec.in: use %{python3_pkgversion}

* Mon Oct 08 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1483c29
- version 4.0.10

* Tue Oct 02 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 32db462
- travis: add fc29

* Tue Oct 02 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 87de0cb
- rpm: add BR: gcc

* Sat Sep 29 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - adadcf4
- rpm: add missing BR: systemd-devel

* Fri Sep 07 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5b20e2b
- version 4.0.9

* Mon Aug 06 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 47783b7
- Merge remote-tracking branch 'qubesos/pr/12'

* Fri Aug 03 2018 unman <unman@thirdeyesecurity.org> - 3103035
- Remove wheezy and trusty builds. Consolidate Build-Depends

* Wed Aug 01 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 586bd96
- debian: unify Build-Depends

* Wed Aug 01 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f03ff8c
- travis: add fc28 and buster

* Wed Aug 01 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5d7702c
- rpm: use build flags provided by the distribution

* Wed Jul 11 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6385bcc
- version 4.0.8

* Wed Jul 11 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0a41f05
- daemon: fix error message format string

* Wed Jul 11 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 2d164cc
- version 4.0.7

* Tue Jul 10 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3cfab77
- windows: automatically determine newest SDK version

* Sat Jul 07 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c79b10d
- windows: update for vs2017

* Sat Jul 07 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b957321
- windows: fix few compile warnings

* Tue May 01 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4579b63
- version 4.0.6

* Tue May 01 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8a1f1c8
- travis: add centos7

* Tue May 01 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a5938f0
- rpm: fix packaging

* Sat Apr 21 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e21c9e3
- travis: update Fedora versions

* Sat Apr 21 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c8e621a
- Merge remote-tracking branch 'qubesos/pr/10'

* Fri Apr 20 2018 Frédéric Pierret <frederic.epitre@orange.fr> - 50c2e72
- Fix GCC8 warnings:

* Tue Apr 03 2018 Frédéric Pierret <frederic.epitre@orange.fr> - 447d8da
- spec.in: add changelog placeholder

* Sun Jan 28 2018 Frédéric Pierret <frederic.epitre@orange.fr> - 320ad1d
- Remove _builddir

* Wed Jan 24 2018 Frédéric Pierret <frederic.epitre@orange.fr> - 61f0696
- remove _sourcedir (put in Makefile-legacy.fedora) and isolate _builderdir

* Wed Jan 24 2018 Frédéric Pierret <frederic.epitre@orange.fr> - 4eeec6b
- Create spec.in and add Source0

* Sun Oct 22 2017 Olivier MEDOC <o_medoc@yahoo.fr> - 5efa37d
- archlinux: build both python2 and python3 bindings

* Wed Oct 04 2017 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 09aef47
- version 4.0.5

* Wed Oct 04 2017 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8856fe0
- Fix handling qdb_list errors

* Fri Sep 29 2017 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3afb1bf
- version 4.0.4

* Fri Sep 29 2017 Frédéric Pierret <frederic.epitre@orange.fr> - f671eab
- Fix CentOS dependencies: python3

* Sat Jul 29 2017 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c39c5fd
- version 4.0.3

* Mon Jul 24 2017 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 19742f0
- python3: use unicode as return type for paths

* Sat Jun 10 2017 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b84ee3b
- version 4.0.2

* Fri Jun 02 2017 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 230b505
- debian: drop non-deterministing orig.tar.gz creation

* Fri Jun 02 2017 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 63e70ca
- debian: fix dependencies

* Mon May 29 2017 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c347db4
- version 4.0.1

* Mon May 29 2017 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3e00f21
- travis: update for Qubes 4.0

* Fri Mar 03 2017 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - eb6b751
- Merge remote-tracking branch 'qubesos/pr/3'

* Sat Feb 25 2017 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 493cffa
- rpm: remove obsolete code

* Sat Feb 25 2017 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 632dda9
- debian: do not disable hardening

* Sat Feb 25 2017 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d9dae76
- debian: add python3 packaging

* Sat Feb 25 2017 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 19fd492
- rpm: add python3 packaging, split python2 bindings into separate package

* Sat Feb 25 2017 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b1cc521
- Add python3 bindings

